searchNodes=[{"doc":"Elixir wrapper for the Argon2 password hashing function.Most applications will just need to use the add_hash/2 and check_pass/3 convenience functions in this module.For a lower-level API, see Argon2.Base.ConfigurationSee the documentation for Argon2.Stats for information about configuration.Argon2Argon2 is the winner of the Password Hashing Competition (PHC).Argon2 is a memory-hard password hashing function which can be used to hash passwords for credential storage, key derivation, or other applications.Argon2 has the following three variants (Argon2id is the default):Argon2d - suitable for applications with no threats from side-channel timing attacks (eg. cryptocurrencies)Argon2i - suitable for password hashing and password-based key derivationArgon2id - a hybrid of Argon2d and Argon2iArgon2i, Argon2d, and Argon2id are parametrized by:A time cost, which defines the amount of computation realized and therefore the execution time, given in number of iterationsA memory cost, which defines the memory usage, given in kibibytesA parallelism degree, which defines the number of parallel threadsMore information can be found in the documentation for the Argon2.Stats module and at the Argon2 reference C implementation repository.Comparison with Bcrypt / Pbkdf2Argon2 has better password cracking resistance than Bcrypt and Pbkdf2. Its main advantage is that, as it is a memory-hard function, it is designed to withstand parallel attacks that use GPUs or other dedicated hardware.","ref":"Argon2.html","title":"Argon2","type":"module"},{"doc":"Hashes a password, using hash_pwd_salt/2, and returns the password hash in a map.This is a convenience function that is especially useful when used with Ecto changesets.OptionsIn addition to the :hash_key option show below, this function also takes options that are then passed on to the hash_pwd_salt/2 function in this module.See the documentation for hash_pwd_salt/2 for further details.:hash_key - the password hash identifierthe default is :password_hashExample with EctoThe put_pass_hash function below is an example of how you can use add_hash to add the password hash to the Ecto changeset.defp put_pass_hash(%Ecto.Changeset{valid?: true, changes: %{password: password}} = changeset) do change(changeset, add_hash(password)) end defp put_pass_hash(changeset), do: changesetThis function will return a changeset with %{password_hash: password_hash} added to the changes map.","ref":"Argon2.html#add_hash/2","title":"Argon2.add_hash/2","type":"function"},{"doc":"Checks the password, using verify_pass/2, by comparing the hash with the password hash found in a user struct, or map.This is a convenience function that takes a user struct, or map, as input and seemlessly handles the cases where no user is found.Options:hash_key - the password hash identifierthis does not need to be set if the key is :password_hash or :encrypted_password:hide_user - run the no_user_verify/1 function if no user is foundthe default is trueExampleThe following is an example of using this function to verify a user's password:def verify_user(%{&quot;password&quot; =&gt; password} = params) do params |&gt; Accounts.get_by() |&gt; check_pass(password) endThe Accounts.get_by function in this example takes the user parameters (for example, email and password) as input and returns a user struct or nil.","ref":"Argon2.html#check_pass/3","title":"Argon2.check_pass/3","type":"function"},{"doc":"Generate a random salt.The default length for the salt is 16 bytes. We do not recommend using a salt shorter than the default.","ref":"Argon2.html#gen_salt/1","title":"Argon2.gen_salt/1","type":"function"},{"doc":"Hashes a password with a randomly generated salt.OptionsIn addition to the :salt_len option shown below, this function also takes options that are then passed on to the hash_password function in the Argon2.Base module.See the documentation for Argon2.Base.hash_password/3 for further details.:salt_len - the length of the random saltthe default is 16 (the minimum is 8) bytesExamplesThe following examples show how to hash a password with a randomly-generated salt and then verify a password:iex&gt; hash = Argon2.hash_pwd_salt(&quot;password&quot;) ...&gt; Argon2.verify_pass(&quot;password&quot;, hash) true iex&gt; hash = Argon2.hash_pwd_salt(&quot;password&quot;) ...&gt; Argon2.verify_pass(&quot;incorrect&quot;, hash) false","ref":"Argon2.html#hash_pwd_salt/2","title":"Argon2.hash_pwd_salt/2","type":"function"},{"doc":"Runs the password hash function, but always returns false.This function is intended to make it more difficult for any potential attacker to find valid usernames by using timing attacks. This function is only useful if it is used as part of a policy of hiding usernames.OptionsThis function should be called with the same options as those used by hash_pwd_salt/2.Hiding usernamesIn addition to keeping passwords secret, hiding the precise username can help make online attacks more difficult. An attacker would then have to guess a username / password combination, rather than just a password, to gain access.This does not mean that the username should be kept completely secret. Adding a short numerical suffix to a user's name, for example, would be sufficient to increase the attacker's work considerably.If you are implementing a policy of hiding usernames, it is important to make sure that the username is not revealed by any other part of your application.","ref":"Argon2.html#no_user_verify/1","title":"Argon2.no_user_verify/1","type":"function"},{"doc":"Verifies a password by hashing the password and comparing the hashed value with a stored hash.See the documentation for hash_pwd_salt/2 for examples of using this function.","ref":"Argon2.html#verify_pass/2","title":"Argon2.verify_pass/2","type":"function"},{"doc":"Lower-level api for Argon2.These functions can be useful if you want more control over some of the options. In most cases, you will not need to call these functions directly.","ref":"Argon2.Base.html","title":"Argon2.Base","type":"module"},{"doc":"Calculate the length of the encoded hash.","ref":"Argon2.Base.html#encodedlen_nif/6","title":"Argon2.Base.encodedlen_nif/6","type":"function"},{"doc":"Translate the error code to an error message.","ref":"Argon2.Base.html#error_nif/1","title":"Argon2.Base.error_nif/1","type":"function"},{"doc":"","ref":"Argon2.Base.html#handle_error/1","title":"Argon2.Base.handle_error/1","type":"function"},{"doc":"Hash a password using Argon2.","ref":"Argon2.Base.html#hash_nif/10","title":"Argon2.Base.hash_nif/10","type":"function"},{"doc":"Hash a password using Argon2.OptionsThere are six options::t_cost - time cost:m_cost - memory usage:parallelism - number of parallel threads:format - output formatthis value can be:encoded - encoded with Argon2 crypt format:raw_hash - raw hash output in hexadecimal format:report - raw hash and encoded hash, together with the options used:encoded is the default:hashlen - length of the hash (in bytes)the default is 32:argon2_type - Argon2 typethis value should be 0 (Argon2d), 1 (Argon2i) or 2 (Argon2id)the default is 2 (Argon2id)The t_cost, m_cost, parallelism and argon2_type can also be set in the config. See the documentation for Argon2.Stats for more information about choosing these values.ExamplesThe following example changes the default t_cost and m_cost:Argon2.Base.hash_password(&quot;password&quot;, &quot;somesaltSOMESALT&quot;, [t_cost: 4, m_cost: 18])In the example below, the Argon2 type is changed to Argon2d:Argon2.Base.hash_password(&quot;password&quot;, &quot;somesaltSOMESALT&quot;, [argon2_type: 0])To use Argon2i, use argon2_type: 1.","ref":"Argon2.Base.html#hash_password/3","title":"Argon2.Base.hash_password/3","type":"function"},{"doc":"","ref":"Argon2.Base.html#init/0","title":"Argon2.Base.init/0","type":"function"},{"doc":"Verify a password using Argon2.","ref":"Argon2.Base.html#verify_nif/3","title":"Argon2.Base.verify_nif/3","type":"function"},{"doc":"Module to provide statistics for the Argon2 password hashing function.The report/1 function in this module can be used to help you configure Argon2.ConfigurationThe following four parameters can be set in the config file (these can all be overridden using keyword options):t_cost - time costthe amount of computation, given in number of iterations8 is the defaultm_cost - memory usage17 is the default - this will produce a memory usage of 128 MiB (2 ^ 17 KiB)parallelism - number of parallel threads4 is the defaultargon2_type - argon2 variant to use0 (Argon2d), 1 (Argon2i) or 2 (Argon2id)2 is the default (Argon2id)It is important to note that the default values are not necessarily the recommended values. A lot will depend on what hardware you are using and how much time you want the hashing function to take. See the Choosing parameters section for more details.Test valuesThe following values can be used to speed up tests.config :argon2_elixir, t_cost: 1, m_cost: 8NB. do not use these values in production.Choosing parametersThe following is a guide on how to choose the parameters.Decide which type to use. If you do not know the difference between the types, choose Argon2id.Decide how many threads to use - the parallelism option.Decide how much memory each call should use - m_cost.Decide how much time each call should take. a. The Argon2 draft guidelines recommend 500 milliseconds (0.5 seconds).Run the function using the values chosen in steps 1-3. Work out the maximum t_cost (number of iterations) such that the running time does not exceed the value chosen in step 4. If the time taken exceeds the value chosen in step 4 even for one iteration, reduce the m_cost accordingly.","ref":"Argon2.Stats.html","title":"Argon2.Stats","type":"module"},{"doc":"Hash a password with Argon2 and print out a report.This function hashes the password and salt with Argon2.Base.hash_password/3 and prints out statistics which can help you choose how to configure Argon2.OptionsIn addition to the options for Argon2.Base.hash_password/3, there are also the following options::password - the password usedthe default is &quot;password&quot;:salt - the salt usedthe default is &quot;somesaltSOMESALT&quot;","ref":"Argon2.Stats.html#report/1","title":"Argon2.Stats.report/1","type":"function"}]